@@ -12,6 +12,14 @@ def flaky(max_runs=None, min_passes=None):
     Decorator used to mark a test as "flaky". When used in conjuction with
     the flaky nosetests plugin, will cause the decorated test to be retried
     until min_passes successes are achieved out of up to max_runs test runs.
+    :param max_runs:
+        The maximum number of times the decorated test will be run.
+    :type max_runs:
+        `int`
+    :param min_passes:
+        The minimum number of times the test must pass to be a success.
+    :type min_passes:
+        `int`
     """
     if max_runs is None:
         max_runs = 2
